@@ -13,13 +13,13 @@ class RobotFactory(object):
         self.number = config(label, "number")
         self.headers = {'Content-Type': 'application/json'}
 
-    def send_message(self, content: str):
+    def send_message(self, content: str, number: str=None):
         try:
             message = {
                 "content": content,
                 "notifyParams": [{
                     "type": "jobNos",
-                    "values": self.number.split(",")
+                    "values": number.split(",") if number != None else self.number.split(",")
                 }]
             }
             _code = 0
